@@ -410,6 +410,106 @@ TO_MULTI_BYTE_EUCJP[95] =
 #endif
 };
 
+static const char *
+TO_MULTI_BYTE__EUCCN[95] =
+{
+	"\241\241",
+	"\243\241",
+	"\243\242",
+	"\243\243",
+	"\243\244",
+	"\243\245",
+	"\243\246",
+	"\243\247",
+	"\243\250",
+	"\243\251",
+	"\243\252",
+	"\243\253",
+	"\243\254",
+	"\243\255",
+	"\243\256",
+	"\243\257",
+	"\243\260",
+	"\243\261",
+	"\243\262",
+	"\243\263",
+	"\243\264",
+	"\243\265",
+	"\243\266",
+	"\243\267",
+	"\243\270",
+	"\243\271",
+	"\243\272",
+	"\243\273",
+	"\243\274",
+	"\243\275",
+	"\243\276",
+	"\243\277",
+	"\243\300",
+	"\243\301",
+	"\243\302",
+	"\243\303",
+	"\243\304",
+	"\243\305",
+	"\243\306",
+	"\243\307",
+	"\243\310",
+	"\243\311",
+	"\243\312",
+	"\243\313",
+	"\243\314",
+	"\243\315",
+	"\243\316",
+	"\243\317",
+	"\243\320",
+	"\243\321",
+	"\243\322",
+	"\243\323",
+	"\243\324",
+	"\243\325",
+	"\243\326",
+	"\243\327",
+	"\243\330",
+	"\243\331",
+	"\243\332",
+	"\243\333",
+	"\243\334",
+	"\243\335",
+	"\243\336",
+	"\243\337",
+	"\243\340",
+	"\243\341",
+	"\243\342",
+	"\243\343",
+	"\243\344",
+	"\243\345",
+	"\243\346",
+	"\243\347",
+	"\243\350",
+	"\243\351",
+	"\243\352",
+	"\243\353",
+	"\243\354",
+	"\243\355",
+	"\243\356",
+	"\243\357",
+	"\243\360",
+	"\243\361",
+	"\243\362",
+	"\243\363",
+	"\243\364",
+	"\243\365",
+	"\243\366",
+	"\243\367",
+	"\243\370",
+	"\243\371",
+	"\243\372",
+	"\243\373",
+	"\243\374",
+	"\243\375",
+	"\243\376",
+};
+
 Datum
 orafce_to_multi_byte(PG_FUNCTION_ARGS)
 {
@@ -441,6 +541,9 @@ orafce_to_multi_byte(PG_FUNCTION_ARGS)
 		case PG_EUC_JIS_2004:
 			map = TO_MULTI_BYTE_EUCJP;
 			break;
+		case PG_EUC_CN:
+			map = TO_MULTI_BYTE__EUCCN;
+			break;
 		/*
 		 * TODO: Add converter for encodings.
 		 */
@@ -521,6 +624,9 @@ orafce_to_single_byte(PG_FUNCTION_ARGS)
 		case PG_EUC_JIS_2004:
 			map = TO_MULTI_BYTE_EUCJP;
 			break;
+		case PG_EUC_CN:
+			map = TO_MULTI_BYTE__EUCCN;
+			break;
 		/*
 		 * TODO: Add converter for encodings.
 		 */
